<?php
/**
 * Implementiert die Seite, die das Gateway neustartet um eine Firmware zu installieren
 * @author Florian Kraatz <fk@beronet.com>
 * @author Miguel Palmer <mp@beronet.com>
 */

class UpdateTool {

	private	$_m,
		$_is_sbc_vm = '0';

	private $_isRequestResponse 	= false,
		$_reasonResponse 	= '';

	private $_param_list = array(
			'permlog'		=> array(
				'file'		=> '/usr/conf/permlog/',
				'title'		=> 'UPDATETOOL_PERMLOG_BUTTON_DIS',
				'tooltip'	=> 'UPDATETOOL_PERMLOG_TOOLTIP_DIS',
			),
			'sbc-fw-update'		=> array(
				'alert'		=> 'UPDATE_TOOL_MESSAGE_DIS',
				'button'	=> 'BUTTON_RESTART_UPDATE',
				'confirm'	=> 'REBOOT_RESET_CONFIRM_REBOOT_DIS',
				'file'		=> '/tmp/firmware_3LI.list',
				'message'	=> 'AVAILABLE_FIRMWARE_TABLE_DIS',
			),
			'sbcvm-fw-update'	=> array(
				'act-call-confirm1' 	=> 'UPDATE_TOOL_CONFIRM_WITHOUTCALLS',
				'act-call-confirm2' 	=> 'UPDATE_TOOL_CONFIRM_WITHCALLS',
				'act-call-title'	=> 'UPDATE_TOOL_CONFIRM_TITLE',
				'alert'			=> 'UPDATE_TOOL_MESSAGE_DIS',
				'error-2'		=> 'UPDATE_TOOL_ERROR_CLEANING',
				'error-3'		=> 'UPDATE_TOOL_ERROR_SAVING_CRON',
				'successful'		=> 'UPDATE_TOOL_SUCCESSFUL',
			),
		);

	private $_data 		= array(),
		$_data_list 	= array(
			'sbcvmupdate-mode'	=> array(
				'default'	=> 'manual',
				'display'	=> 'fieldSelect',
				'key'		=> 'sbcvmupdate-mode',
				'options'	=> array(
					'select' => array(
						'manual'	=> 'UPDATE_TOOL_DATA_SBCVM_MANUAL',
						'daily'		=> 'UPDATE_TOOL_DATA_SBCVM_DAILY',
						'weekly'	=> 'UPDATE_TOOL_DATA_SBCVM_WEEKLY',
						'monthly'	=> 'UPDATE_TOOL_DATA_SBCVM_MONTHLY',
					),
				),
				'title'		=> 'UPDATE_TOOL_SBCVM_MODE_DIS',
				'tooltip'	=> 'UPDATE_TOOL_SBCVM_MODE_TOOLTIP',
			),
			'sbcvmupdate-shownotif'	=> array(
				'default'	=> 1,
				'display'	=> 'fieldCheckbox',
				'key'		=> 'sbcvmupdate-shownotif',
				'title'		=> 'UPDATE_TOOL_SHOWNOTIF_DIS',
				'tooltip'	=> 'UPDATE_TOOL_SHOWNOTIF_TOOLTIP',
			),
			'sbcvmupdate-reboot'	=> array(
				'default'	=> 1,
				'display'	=> 'fieldCheckbox',
				'key'		=> 'sbcvmupdate-reboot',
				'title'		=> 'UPDATE_TOOL_REBOOT_DIS',
				'tooltip'	=> 'UPDATE_TOOL_REBOOT_TOOLTIP',
			),
			'sbcvmupdate-update'	=> array(
				'default'	=> null,
				'display'	=> 'fieldButton',
				'key'		=> 'sbcvmupdate-update',
				'title'		=> 'UPDATE_TOOL_BUTTON_UPDATE',
			),
			'sbcvmupdate-save'	=> array(
				'default'	=> null,
				'display'	=> 'fieldButton',
				'key'		=> 'sbcvmupdate-save',
				'title'		=> 'BUTTON_SAVE',
			), 
		);

	/* [CONSTRUCTOR] */
	function __construct($m, $get = array(), $post = array(), $session = array()) {
		$this->_m = $m;

		$image_dir = "/tmp/images";
		if (!file_exists($image_dir)) {
			system("mkdir -p $image_dir");
		}

		require_once('/usr/fallback/beroConf.php');
		$bc = new beroConf('root'); 
		$this->_is_sbc_vm = ($bc->get('root', 'is-sbc-vm') == 1) ? 1 : 0;
		if ($this->_is_sbc_vm) {
			// set data
			foreach ($this->_data_list as $key => $params) {
				$data = $bc->get('root', $key);
				$this->_data[$key] = strlen($data) == 0 ? $params['default'] : $data;
			}
		}

		// set error
		if (isset($get['error'])) {
			$this->_isRequestResponse = true;
			switch ($get['error']) {
				case 1:
					$this->_reasonResponse = Helper::displayErrorMessage($get['request'], $get['checkor'], $get['key']);
					break;
				case 2:
				case 3:
					$this->_reasonResponse = "<div id='update-info' class='text-center' style='margin-top: 5px; color: red;'>"
								. constant($this->_param_list['sbcvm-fw-update']["error-{$get['error']}"])
								. "</div>\n";
					break;
				default:
					$this->_reasonResponse = "<div id='update-info' class='text-center' style='margin-top: 5px; color: red;'>"
								. constant()
								. "</div>\n";
					break;
			}
		}
		// set success
		else if (isset($get['success'])) {
			$this->_isRequestResponse = true;
			$this->_reasonResponse = "<div id='update-info' class='text-center' style='margin-top: 5px; color: green;'>"
						. constant()
						. "</div>\n";
		}
	}

	/* [PUBLIC METHODS] */
	public function display() {
		$title = array(
			0 => 'UPDATE_TOOL_TITLE_DIS',
			1 => 'UPDATE_TOOL_SBCVM_TITLE_DIS',
		);
		$name = $title[$this->_is_sbc_vm];
		include('./includes/header.php');
		$ret .= "\n";

		$display_list = array(
			0 => '_displaySbc',
			1 => '_displaySbcVm',
		);
		$display = $display_list[$this->_is_sbc_vm];

		$ret .=   ($this->_isRequestResponse ? $this->_reasonResponse : "<div id='update-info' class='text-center' style='margin-top: 5px; color: green;'></div>\n")
			. "<div id='content' style='margin-top:45px;'>\n"
			. $this->$display("\t")
			. "</div>\n";
		return $ret;
	}

	/* [PRIVATE METHODS] */
	private function _buttonDownloadLogFile($tab = "") {
		$permlog = $this->_param_list['permlog'];
		if (!file_exists($permlog['file'])) {
			return '';
		}
		$dir_contents = scandir($permlog['file']);
		$file_count = 0;
		foreach ($dir_contents as $logfile) {
			if (($logfile == '.') || ($logfile == '..')) {
				continue;
			}
			$file_count++;
		}
		if ($file_count == 0) {
			return '';
		}
		$html =   "$tab<form method='POST'>\n"
			. "$tab\t<div class='text-center'>\n"
			. "$tab\t\t<input type='button' class='btn btn-default' value='". constant($permlog['title']) ."'"
			.	"onclick='window.location.href=\"modules/UpdateTool/permlog.php\";' onmouseover='Tip(\"". constant($permlog['tooltip']) ."\");' onmouseout='UnTip();'/>\n"
			. "$tab\t</div>\n"
			. "$tab</form>\n";
		return $html;
	}

	private function _displaySbc($tab = "") {
		$permlog = $this->_param_list['permlog'];
		$sbc_update = $this->_param_list['sbc-fw-update'];

		//available FW version form FW list
		$html_fw = '';
		if (file_exists($sbc_update['file']) && $get_fw_list = file_get_contents($permlog['file'])) {
			if (preg_match("/Firmware ([0-9.]{1,5});appfs/", $get_fw_list, $fw_matched)) { 
				$html_fw = 	  "$tab<table class='table table-striped table-bordered' style='width:30% !important; margin:auto; text-align: center;'>\n"
						. "$tab\t<tr><th class='text-center'>". constant($sbc_update['message']) ."</th></tr>\n"
						. "$tab\t<tr><td>{$fw_matched[1]}</td></tr>\n"
						. "$tab</table>\n";
			}	
		}		
		ob_start();
		?>
		<script>
        	function checkupdate(option) {
          	if (option != "0") {
           		alert('<?php echo constant($sbc_update['alert']); ?>');
           		return false;
           	}
           	conf = confirm('<?php echo constant($sbc_update['confirm']); ?>');
						if (conf == false) {
            	return false;
            }
						else{
            	return true;
            }
        	}
    </script>
		<?php
		$html = ob_get_clean();
		$html .= $html_fw
			. "$tab<div class='text-center'>\n"
			. "$tab\t<form method='POST' action='./reboot.php' onsubmit='return checkupdate(\"". Helper::getActivateOption() ."\");'>\n"
                    	. "$tab\t\t<input type='hidden' name='action' value='reboot'>\n"
			. "$tab\t\t<input type='hidden' name='v' value='Yes'>\n"
			. "$tab\t\t<input type='hidden' name='module' value='fw_update'>\n"
			. "$tab\t\t<input type='submit' class='btn btn-default' name='submit' value='". constant($sbc_update['button']) ."'/>\n"
			. "$tab\t</form>\n"
			. $this->_buttonDownloadLogFile($tab)
			. "$tab</div>\n";
		return $html;
	}

	private function _displaySbcVm($tab = '') {
		require_once('./includes/Helper/HelperHtml.php');

		$html = "$tab<form method='POST' id='id_sbcvm_form' class='form-horizontal' action='./modules/UpdateTool/updatetool_submit.php'>\n";
		foreach ($this->_data_list as $key => $params) {
			$function = $params['display'];
			$html .= HelperHtml::$function($key, $this->_data[$key], $params, "$tab\t");
		}
		$html .= "$tab</form>\n";

		$message = $this->_param_list['sbcvm-fw-update'];
		ob_start();
		?>
		<script type="text/javascript" language="javascript">
			window.ajaxLoading = false;
			function doUpdate() {
				$('#update-info').html('<?php echo $waiting; ?>');
				$.ajax({
					cache: false,
					data: {
						'sbcvmupdate-reboot': $('#id_sbcvmupdate-reboot').is(':checked'),
					},
					error: function(request, stat, error) {
						$('#update-info').css('color', 'red');
						$('#update-info').html(error);
						document.getElementById("wait_div").style.display = "none";	
					},
					success: function() {
						$('#update-info').css('color', 'green');
						$('#update-info').html('<?php echo constant($message['successful']); ?>');
						document.getElementById("wait_div").style.display = "none";
					},
					timeout: 60000,
					type: 'POST',
					url: "./modules/UpdateTool/updatetool_ajax.php",
				});
			}
			function manualUpdate(isActiveCalls, callback) {
				var message;
				var title = '<?php echo constant($message['act-call-title']); ?>';
				if (isActiveCalls == 0) {
					message = '<?php echo constant($message['act-call-confirm1']); ?>';
				}
				else {
					message = '<?php echo constant($message['act-call-confirm2']); ?>';
				}
				$("#dialog-confirm").dialog({
					autoOpen: false,
					modal: true
				});
				$('#dialog-confirm').dialog('option', 'title', title);	
				$("#dialogtext").html(message);
				$("#dialog-confirm").dialog("open");
				$("#dialog-confirm").dialog({
					buttons: {
						"Confirm": function () {
							$(this).dialog("close");
							window.ajaxLoading = false;
							$('#id_sbcvmupdate-update').prop('disabled', false);
							document.getElementById("wait_div").style.display = "block";	
							callback();
						},
						"Cancel": function () {
							$(this).dialog("close");
							window.ajaxLoading = false;
							$('#id_sbcvmupdate-update').prop('disabled', false);
						}
					}
				});
			}
			function showFields(isManual) {
				if (isManual) {
					$('#id_sbcvmupdate-update').show();
					$('#iddiv_sbcvmupdate-shownotif').hide();
					$('#id_sbcvmupdate-save').hide();
				}
				else {
					$('#id_sbcvmupdate-update').hide();
					$('#iddiv_sbcvmupdate-shownotif').show();
					$('#id_sbcvmupdate-save').show();
				}
			}
			$('#id_sbcvmupdate-mode').change(function() {
				showFields(this.value === 'manual');
			});
			$(document).ready(function() {
				showFields(<?php echo ($this->_data['sbcvmupdate-mode'] == 'manual' ? 'true' : 'false'); ?>);
				$('#id_sbcvm_form').submit(function (evt) {
					// save request -> submit
					if ($('#id_sbcvmupdate-save').is(':visible') == true) {
						return;
					}
					// manual update -> cancel submit and realize an AJAX request
					evt.preventDefault();
					if (window.ajaxLoading) {
						return;
					}
					else if (<?php echo Helper::getActivateOption(); ?> != 0) {
						alert('<?php echo constant($message['alert']); ?>');
						return;
					}
					window.ajaxLoading = true;
					$.ajax({
						cache: false,
						error: function(request, stat, error) {
							$('#update-info').css('color', 'red');
							$('#update-info').html(error);
							window.ajaxLoading = false;
							$('#id_sbcvmupdate-update').prop('disabled', false);
						},
						success: function(data) {
							manualUpdate(data, doUpdate);
						},
						timeout: 2000,
						url: "./misc/getTotalCalls.php",
					});
				});
			});
		</script>
		<?php
		return $html. ob_get_clean() ."\n";
	}
}
?>
